@@ -3,7 +3,7 @@ import inspect
 import json
 from functools import partial
 from hashlib import sha256
-from typing import Any, Awaitable, Callable, Coroutine, Dict, Optional, Union
+from typing import Any, Awaitable, Callable, Coroutine, Dict, Optional, TypeVar, Union
 
 from aioredis.client import Redis
 from fastapi import FastAPI, Request, Response, params
@@ -15,11 +15,12 @@ from .backend import DEFAULT_LOCK_TIMEOUT, EX, BaseCacheBackend
 from .redis import RedisCacheBackend
 
 MIN_AUTOREFRESH_RATE = 60
+_ResponseT = TypeVar("_ResponseT")
 
 
-class CachedResponse(Exception):
-    def __init__(self, *args, content: str, ttl: int) -> None:  # noqa:WPS110
-        self.content = content  # noqa:WPS110
+class CachedResponse(Exception):  # noqa: N818
+    def __init__(self, *args, content: str, ttl: int) -> None:
+        self.content = content
         self.ttl = ttl
 
     def __repr__(self) -> str:
@@ -101,7 +102,7 @@ class Cache:
     def get_key(self, cache_id: str = "") -> str:
         return f"{self.namespace}{cache_id}"
 
-    def set(self, response: Any, cache_id: str = "") -> dict:  # noqa: WPS125
+    def set(self, response: _ResponseT, cache_id: str = "") -> _ResponseT:  # noqa: WPS125
         if isinstance(response, Response):
             cache = response.body
         else:
@@ -110,23 +111,34 @@ class Cache:
             asyncio.ensure_future(self.backend.set(key=self.get_key(cache_id), value=cache, expire=self._expire))
         return response
 
+    def mset(self, cache: dict[str, Any]) -> dict[str, Any]:
+        encoded_cache = {self.get_key(k): json.dumps(jsonable_encoder(v)) for k, v in cache.items()}
+        asyncio.ensure_future(self.backend.mset(encoded_cache, self._expire))
+        return cache
+
     async def get(
         self,
         cache_id: str = "",
         with_lock=True,
         decode=True,
         lockspace: Optional[str] = None,
-    ):
+    ) -> Any:
         if self._cache_control:
             return None
         cached, _ = await self.backend.get(
             key=self.get_key(cache_id), timeout=self._lock_timeout, with_lock=with_lock, lockspace=lockspace
         )
-        if cached is not None and decode:
-            return json.loads(cached)
-        return cached
+        return json.loads(cached) if cached is not None and decode else cached
 
-    async def raise_try(self, cache_id: str = "", with_lock=True, lockspace: Optional[str] = None):
+    async def mget(self, *cache_ids: str, decode=True) -> dict[str, Any]:
+        if not cache_ids:
+            return {}
+        cache = await self.backend.mget(*map(self.get_key, cache_ids))
+        if decode:
+            return {k.removeprefix(self.namespace): json.loads(v) for k, v in cache.items()}
+        return {k.removeprefix(self.namespace): v for k, v in cache.items()}
+
+    async def raise_try(self, cache_id: str = "", with_lock=True, lockspace: Optional[str] = None) -> None:
         """Try to raise Response from cache otherwise do nothing.
 
         Args:
@@ -156,7 +168,7 @@ class Cache:
     async def init(cls, app: FastAPI, cache_client: Redis, autorefresh: bool = True):
         cls.app = app
         if isinstance(cache_client, Redis):
-            cls.backend = RedisCacheBackend(cache_client)
+            cls.backend = await RedisCacheBackend(cache_client)
         else:
             raise TypeError(f"Unsupported {type(cache_client)} cache client type.")
         app.add_exception_handler(CachedResponse, cached_response_handler)
@@ -216,5 +228,5 @@ def cached_response_handler(request: Request, exc: CachedResponse) -> Response:
     return response
 
 
-def hashsum(obj: str) -> str:  # noqa: WPS110
+def hashsum(obj: str) -> str:
     return sha256(obj.encode()).hexdigest()
