@@ -1,5 +1,5 @@
 import asyncio
-from typing import Awaitable, Optional, Tuple
+from typing import Any, Awaitable, Generator, Optional, Tuple
 
 from aioredis.client import KeyT, Redis
 
@@ -16,6 +16,13 @@ class RedisCacheBackend(BaseCacheBackend):  # noqa: WPS214
         self._redis = redis
         self._db = self.client.connection_pool.connection_kwargs["db"]
 
+    def __await__(self) -> Generator[Any, None, "RedisCacheBackend"]:  # noqa:WPS611
+        """Setup keyspace notification events required by `_get_or_wait`"""
+        yield from self._redis.execute_command(  # noqa:WPS609
+            "config", "set", "notify-keyspace-events", "KEA"
+        ).__await__()
+        return self
+
     @property
     def client(self) -> Redis:
         """Client might be used to perform direct redis calls
@@ -55,7 +62,7 @@ class RedisCacheBackend(BaseCacheBackend):  # noqa: WPS214
             except (asyncio.exceptions.TimeoutError, LookupError):
                 return default, DEFAULT_TTL
 
-    async def set(self, key: KT, value: VT, expire: EX, unlock=True) -> bool:  # noqa: WPS110
+    async def set(self, key: KT, value: VT, expire: EX, unlock=True) -> bool:
         async with self._redis.client() as conn:
             if not unlock:
                 return await conn.set(key, value, ex=expire)
@@ -65,6 +72,16 @@ class RedisCacheBackend(BaseCacheBackend):  # noqa: WPS214
             is_setted, _ = await pipe.execute()
             return is_setted
 
+    async def mget(self, *keys: KT) -> dict[KT, VT]:
+        async with self._redis.client() as conn:
+            return {k: v for k, v in zip(keys, await conn.mget(keys)) if v is not None}
+
+    async def mset(self, values: dict[KT, VT], expire: EX) -> None:
+        async with self._redis.pipeline() as pipe:
+            for key, value in values.items():
+                pipe.set(key, value, ex=expire)
+            await pipe.execute()
+
     async def expire(self, key: KT, ttl: TTL) -> bool:
         async with self._redis.client() as conn:
             return await conn.expire(key, ttl)
@@ -109,5 +126,5 @@ class RedisCacheBackend(BaseCacheBackend):  # noqa: WPS214
         async with self._redis.pipeline() as pipe:
             pipe.get(key)
             pipe.ttl(key)
-            value, ttl = await pipe.execute()  # noqa: WPS110
+            value, ttl = await pipe.execute()
             return value.decode(), ttl
